/**
 *
 *   Copyright 2014 sourceforge.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
package org.gwtopenmaps.openlayers.client;

import org.gwtopenmaps.openlayers.client.event.Events;
import org.gwtopenmaps.openlayers.client.util.JSObject;
import org.gwtopenmaps.openlayers.client.util.JSObjectWrapper;

/**
 * Wrapper object for OpenLayer objects.
 *
 * @author Erdem Gunay
 * @author Edwin Commandeur
 *
 */
public class OpenLayersObjectWrapper extends JSObjectWrapper {

	protected OpenLayersObjectWrapper(JSObject openLayersObject)
	{
		super(openLayersObject);
	}

	public static OpenLayersObjectWrapper narrowToOpenLayersObjectWrapper(JSObject element)
	{
		return (element == null)?null: new OpenLayersObjectWrapper(element);
	}

	/**
	 *
	 * @return Events - see {@link org.gwtopenmaps.openlayers.client.event.Events},
	 *  	null if the object does not fire events via event system.
	 */
	public Events getEvents() {
		//intentionally defined here instead of in OpenLayersEObjectWrapper
		// so you can always do Xxx.getEvents().register("eventname", ...)
		return Events.narrowToEvents(OpenLayersObjectWrapperImpl.getEvents(getJSObject()));
	}

	/**
	 * Each OpenLayers object has a CLASS_NAME property.
	 *
	 * Some classes, like Layer and it's subclasses have a public id
	 * property which is generally composed of the CLASS_NAME + _Nr
	 * where Nr is some integer generated by OpenLayers
	 *
	 * @return String - fully qualified OpenLayers class name
	 */
	public String getClassName(){
		return OpenLayersObjectWrapperImpl.getClassName(getJSObject());
	}

}
